# Endpoints

- [Valves API](valves.md)
- [Meters API](meters.md)
- [Virtual Meters API](virtual_meters.md)
- [Programs API](programs.md)
- [Analog Inputs API](analog_inputs.md)
- [Sensors API](sensors.md)
- [Accumulations API](accumulations.md)
